@@ -45,6 +45,6 @@
 #define GLIBTOP_SUID_PROC_AFFINITY	0
 #define GLIBTOP_SUID_PROC_WD		0
 #define GLIBTOP_SUID_PPP		0
-#define GLIBTOP_SUID_PROC_FILE		0
+#define GLIBTOP_SUID_PROC_OPEN_FILES		0
 
 #endif /* __CYGWIN__GLIBTOP_SERVER_H__ */
